==> campsite-2.6.1.tar.gz: campsite/implementation/management/priv/lang/sh/issues.php <==
<?php 
regGS("Change issue status", "");
regGS("The values you are trying to set conflict with issue \"$1$2. $3 ($4)$5\".", "");
regGS("The number must be unique for each issue in this publication of the same language.", "");
regGS("The language and URL name must be unique for each issue in this publication.", "");
regGS("Issue created.", "");
regGS("Issue updated", "");
regGS("Could not save the changes to the issue.", "");
regGS("Unpublish on: $1", "");
regGS("There are $1 articles in this issue.", "");
regGS("The issue $1 has been deleted.", "");
regGS("Schedule", "");
regGS("Publish on: $1", "");
regGS("Publish Date $1", "");
regGS("Deleted issue", "");
regGS("Delete issue", "");
regGS("Click here to publish this issue", "");
regGS("A total of $1 articles were deleted.", "");
regGS("Name<BR><SMALL>(click to see sections)</SMALL>", "Naziv<br><small>(kliknite za pregled rubrika)</small>");
regGS("Delete issue $1", "Obriši izdanje $1");
regGS("Publish articles", "Objavi tekstove");
regGS("You do not have the right to change issues.", "Nemate pravo da promenenite podatke o izdanju");
regGS("Are you sure you want to change the issue $1 status from $2 to $3?", "Da li ste sigurni da želite da promenite status izdanja $1 iz $2 u $3?");
regGS("Add new translation", "Dodaj novi prevod");
regGS("You do not have the right to add issues.", "Nemate pravo da dodajete izdanja");
regGS("The issue $1 has been successfuly added.", "Izdanje $1 je uspešno dodato");
regGS("The issue could not be added.", "Izdanje ne može biti dodato");
regGS("Change issue details", "Promeni detalje o izdanju");
regGS("You do not have the right to change issue details.", "Nemate pravo da menjate podatke o izdanju");
regGS("Publication date<BR><SMALL>(yyyy-mm-dd)</SMALL>", "Datum objavljivanja<br><small>(gggg-mm-dd)</small>");
regGS("Front Page Template", "Šablon za prvu stranu");
regGS("Issue $1 updated in publication $2", "Izdanje $1 je izmenjeno u publikaciji $2");
regGS("You do not have the right to delete issues.", "Nemate pravo da brišete izdanja");
regGS("Are you sure you want to delete the issue $1?", "Sigurni ste da želite da obrišete izdanje $1?");
regGS("Use the structure of the previous issue", "Iskoristi strukturu prethodnog izdanja");
regGS("Copy the entire structure in all languages from the previous issue except for content.", "Prekopiraj celokupnu strukturu u svim jezicima iz prethodnog izdanja, osim sadržaja");
regGS("You may modify it later if you wish.", "Možete ga promeniti kasnije ako želite.");
regGS("Create a new structure", "Napravi novu strukturu");
regGS("Create a complete new structure.", "Napravi potpuno novu strukturu.");
regGS("You must define an issue type for each language and then sections for them.", "Morate definisati tip izdanja za svaki jezik a potom i njegove rubrike.");
regGS("Copy previous issue", "Prekopiraj prethodno izdanje");
regGS("No previous issue.", "Nema prethodnog izdanja.");
regGS("Copy structure from issue number $1", "Prekopiraj strukturu iz izdanja $1");
regGS("New issue $1 from $2 in publication $3", "Novo izdanje $1 iz $2 u publikaciji $3");
regGS("Delete entry", "Obriši unos");
regGS("Issue Publishing Schedule", "Raspored automatskog objavljivanja izdanja");
regGS("Invalid Input: $1", "Pogrešan unos: $1");
regGS("Issue Number", "Broj izdanja");
regGS("Go To Sections", "Idi na rubrike");
regGS("Issue automatic publishing schedule", "Raspored automatskog objavljivanja izdanja");
regGS("Changing issue status", "Menjanje statusa izdanja");
regGS("Status of the issue $1 has been changed from $2 to $3", "Status izdanja $1 je promenjen iz $2 u $3");
regGS("Status of the issue $1 could not be changed.", "Status izdanja $1 ne može biti izmenjen");
regGS("Updating issue", "Menjanje izdanja");
regGS("Changing issue's details", "Promena podataka o izdanju");
regGS("The issue $1 has been successfuly changed.", "Izdanje $1 je uspešno promenjeno");
regGS("The issue could not be changed.", "Izdanje ne može biti izmenjeno");
regGS("Changing issue template", "Menjanje šablona za izdanje");
regGS("You do not have the right to change issue templates.", "Nemate pravo da menjate šablone za izdanje");
regGS("Changing issue template for front page", "Menjanje šablona izdanja za početnu stranu");
regGS("Changing issue template for single article", "Menjanje šablona izdanja za stranu sa člankom");
regGS("The template has been successfully changed.", "Šablon je uspešno promenjen");
regGS("Issue template for publication $1 changed to $2", "Šablon izdanja za publikaciju $1 promenjen u $2");
regGS("Issue template for single articles from $1 changed to $2", "Šablon izdanja za stranu sa tekstom iz $1 promenjen u $2");
regGS("The template could not be changed.", "Šablon ne može biti promenjen");
regGS("There was an error reading the language parameter.", "Greška pri čitanju parametra jezika.");
regGS("There was an error reading the publication parameter.", "Greška pri čitanju parametra publikacije.");
regGS("There was an error reading the issue parameter.", "Greška pri čitanju parametra izdanja.");
regGS("There was an error scheduling the $1 action on $2", "Došlo je do greške pri zakazivanju akcije $1 za $2");
regGS("The action scheduled on $1 could not be deleted.", "Akcija predviđena za $1 ne može biti obrisana.");
?>

==> campsite-2.6.6.tar.gz: campsite/implementation/management/priv/lang/sh/issues.php <==
<?php 
regGS("Change issue status", "Promeni status izdanja");
regGS("The values you are trying to set conflict with issue \"$1$2. $3 ($4)$5\".", "Vrednost koju pokušavate sa postavite je u konfliktu sa izdanjem \"$1$2. $3 ($4)$5\".");
regGS("The number must be unique for each issue in this publication of the same language.", "Broj mora biti jedinstven za svako izdanje u publikaciji u okviru jednog jezika.");
regGS("The language and URL name must be unique for each issue in this publication.", "Jezik i URL ime moraju biti jedinstveni za svako izdanje u ovoj publikaciji.");
regGS("Issue created.", "Izdanje je napravljeno.");
regGS("Issue updated", "Izdanje je izmenjeno.");
regGS("Could not save the changes to the issue.", "Nije moguće snimiti izmene na izdanju.");
regGS("Unpublish on: $1", "Povuci: $1");
regGS("There are $1 articles in this issue.", "U izdanju se nalazi $1 članaka.");
regGS("The issue $1 has been deleted.", "Izdanje $1 je obrisano.");
regGS("Schedule", "Zakaži");
regGS("Publish on: $1", "Objavi u: $1");
regGS("Publish Date $1", "Datum objavljivanja $1");
regGS("Deleted issue", "Obrisano izdanje");
regGS("Delete issue", "Obriši izdanje");
regGS("Click here to publish this issue", "Kliknite ovde da objavite ovo izdanje");
regGS("A total of $1 articles were deleted.", "Ukupno je obrisano $1 članka .");
regGS("Name<BR><SMALL>(click to see sections)</SMALL>", "Naziv<br><small>(kliknite za pregled rubrika)</small>");
regGS("Delete issue $1", "Obriši izdanje $1");
regGS("Publish articles", "Objavi tekstove");
regGS("You do not have the right to change issues.", "Nemate pravo da promenenite podatke o izdanju");
regGS("Are you sure you want to change the issue $1 status from $2 to $3?", "Da li ste sigurni da želite da promenite status izdanja $1 iz $2 u $3?");
regGS("Add new translation", "Dodaj novi prevod");
regGS("You do not have the right to add issues.", "Nemate pravo da dodajete izdanja");
regGS("The issue $1 has been successfuly added.", "Izdanje $1 je uspešno dodato");
regGS("The issue could not be added.", "Izdanje ne može biti dodato");
regGS("Change issue details", "Promeni detalje o izdanju");
regGS("You do not have the right to change issue details.", "Nemate pravo da menjate podatke o izdanju");
regGS("Publication date<BR><SMALL>(yyyy-mm-dd)</SMALL>", "Datum objavljivanja<br><small>(gggg-mm-dd)</small>");
regGS("Front Page Template", "Šablon za prvu stranu");
regGS("Issue $1 updated in publication $2", "Izdanje $1 je izmenjeno u publikaciji $2");
regGS("You do not have the right to delete issues.", "Nemate pravo da brišete izdanja");
regGS("Are you sure you want to delete the issue $1?", "Sigurni ste da želite da obrišete izdanje $1?");
regGS("Use the structure of the previous issue", "Iskoristi strukturu prethodnog izdanja");
regGS("Copy the entire structure in all languages from the previous issue except for content.", "Prekopiraj celokupnu strukturu u svim jezicima iz prethodnog izdanja, osim sadržaja");
regGS("You may modify it later if you wish.", "Možete ga promeniti kasnije ako želite.");
regGS("Create a new structure", "Napravi novu strukturu");
regGS("Create a complete new structure.", "Napravi potpuno novu strukturu.");
regGS("You must define an issue type for each language and then sections for them.", "Morate definisati tip izdanja za svaki jezik a potom i njegove rubrike.");
regGS("Copy previous issue", "Prekopiraj prethodno izdanje");
regGS("No previous issue.", "Nema prethodnog izdanja.");
regGS("Copy structure from issue number $1", "Prekopiraj strukturu iz izdanja $1");
regGS("New issue $1 from $2 in publication $3", "Novo izdanje $1 iz $2 u publikaciji $3");
regGS("Delete entry", "Obriši unos");
regGS("Issue Publishing Schedule", "Raspored automatskog objavljivanja izdanja");
regGS("Invalid Input: $1", "Pogrešan unos: $1");
regGS("Issue Number", "Broj izdanja");
regGS("Go To Sections", "Idi na rubrike");
regGS("There was an error reading the language parameter.", "Greška pri čitanju parametra jezika.");
regGS("There was an error reading the publication parameter.", "Greška pri čitanju parametra publikacije.");
regGS("There was an error reading the issue parameter.", "Greška pri čitanju parametra izdanja.");
regGS("There was an error scheduling the $1 action on $2", "Došlo je do greške pri zakazivanju akcije $1 za $2");
regGS("The action scheduled on $1 could not be deleted.", "Akcija predviđena za $1 ne može biti obrisana.");
regGS("Issue automatic publishing schedule", "Raspored automatskog objavljivanja izdanja");
regGS("Changing issue status", "Menjanje statusa izdanja");
regGS("Status of the issue $1 has been changed from $2 to $3", "Status izdanja $1 je promenjen iz $2 u $3");
regGS("Status of the issue $1 could not be changed.", "Status izdanja $1 ne može biti izmenjen");
regGS("Updating issue", "Menjanje izdanja");
regGS("Changing issue's details", "Promena podataka o izdanju");
regGS("The issue $1 has been successfuly changed.", "Izdanje $1 je uspešno promenjeno");
regGS("The issue could not be changed.", "Izdanje ne može biti izmenjeno");
regGS("Changing issue template", "Menjanje šablona za izdanje");
regGS("You do not have the right to change issue templates.", "Nemate pravo da menjate šablone za izdanje");
regGS("Changing issue template for front page", "Menjanje šablona izdanja za početnu stranu");
regGS("Changing issue template for single article", "Menjanje šablona izdanja za stranu sa člankom");
regGS("The template has been successfully changed.", "Šablon je uspešno promenjen");
regGS("Issue template for publication $1 changed to $2", "Šablon izdanja za publikaciju $1 promenjen u $2");
regGS("Issue template for single articles from $1 changed to $2", "Šablon izdanja za stranu sa tekstom iz $1 promenjen u $2");
regGS("The template could not be changed.", "Šablon ne može biti promenjen");
?>
